==> open-xchange-mobile-push-plugin_1.0.1.orig.tar.bz2: open-xchange-mobile-push-plugin-1.0.1/com.openexchange.mobilepush.events.json/src/com/openexchange/mobilepush/json/actions/PublicInfoAction.java <==
/*
 *
 *    OPEN-XCHANGE legal information
 *
 *    All intellectual property rights in the Software are protected by
 *    international copyright laws.
 *
 *
 *    In some countries OX, OX Open-Xchange, open xchange and OXtender
 *    as well as the corresponding Logos OX Open-Xchange and OX are registered
 *    trademarks of the Open-Xchange, Inc. group of companies.
 *    The use of the Logos is not covered by the GNU General Public License.
 *    Instead, you are allowed to use these Logos according to the terms and
 *    conditions of the Creative Commons License, Version 2.5, Attribution,
 *    Non-commercial, ShareAlike, and the interpretation of the term
 *    Non-commercial applicable to the aforementioned license is published
 *    on the web site http://www.open-xchange.com/EN/legal/index.html.
 *
 *    Please make sure that third-party modules and libraries are used
 *    according to their respective licenses.
 *
 *    Any modifications to this package must retain all copyright notices
 *    of the original copyright holder(s) for the original code used.
 *
 *    After any such modifications, the original and derivative code shall remain
 *    under the copyright of the copyright holder(s) and/or original author(s)per
 *    the Attribution and Assignment Agreement that can be located at
 *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
 *    given Attribution for the derivative code and a license granting use.
 *
 *     Copyright (C) 2004-2020 Open-Xchange, Inc.
 *     Mail: info@open-xchange.com
 *
 *
 *     This program is free software; you can redistribute it and/or modify it
 *     under the terms of the GNU General Public License, Version 2 as published
 *     by the Free Software Foundation.
 *
 *     This program is distributed in the hope that it will be useful, but
 *     WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY
 *     or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public License
 *     for more details.
 *
 *     You should have received a copy of the GNU General Public License along
 *     with this program; if not, write to the Free Software Foundation, Inc., 59
 *     Temple Place, Suite 330, Boston, MA 02111-1307 USA
 *
 */

package com.openexchange.mobilepush.json.actions;

import javax.servlet.http.HttpServletRequest;
import org.json.JSONException;
import org.json.JSONObject;
import com.openexchange.ajax.requesthandler.AJAXRequestResult;
import com.openexchange.exception.OXException;
import com.openexchange.mobilepush.json.MobilePushRequest;
import com.openexchange.server.ServiceLookup;
import com.openexchange.session.Session;
import com.openexchange.tools.session.ServerSession;


/**
 * {@link PublicInfoAction}
 *
 * @author <a href="mailto:thorben.betten@open-xchange.com">Thorben Betten</a>
 * @since v7.8.0
 */
public class PublicInfoAction extends AbstractMobilePushAction {

    /**
     * Initializes a new {@link PublicInfoAction}.
     */
    public PublicInfoAction(ServiceLookup services) {
        super(services);
    }

    @Override
    protected AJAXRequestResult perform(MobilePushRequest req) throws OXException, JSONException {
        ServerSession session = req.getSession();

        JSONObject jResponse = new JSONObject(2);

        String publicSessionId = (String) session.getParameter(Session.PARAM_ALTERNATIVE_ID);
        if (null == publicSessionId) {
            return new AJAXRequestResult(jResponse, "json");
        }

        HttpServletRequest httpRequest = req.getRequest().optHttpServletRequest();
        if (null == httpRequest) {
            return new AJAXRequestResult(jResponse, "json");
        }

        String publicSessionCookieName = com.openexchange.ajax.LoginServlet.getPublicSessionCookieName(httpRequest);
        jResponse.put(publicSessionCookieName, publicSessionId);
        return new AJAXRequestResult(jResponse, "json");
    }

}

==> open-xchange-mobile-push-plugin_1.4.1.orig.tar.bz2: open-xchange-mobile-push-plugin-1.4.1/com.openexchange.mobilepush.events.json/src/com/openexchange/mobilepush/json/actions/PublicInfoAction.java <==
/*
 *
 *    OPEN-XCHANGE legal information
 *
 *    All intellectual property rights in the Software are protected by
 *    international copyright laws.
 *
 *
 *    In some countries OX, OX Open-Xchange, open xchange and OXtender
 *    as well as the corresponding Logos OX Open-Xchange and OX are registered
 *    trademarks of the OX Software GmbH group of companies.
 *    The use of the Logos is not covered by the GNU General Public License.
 *    Instead, you are allowed to use these Logos according to the terms and
 *    conditions of the Creative Commons License, Version 2.5, Attribution,
 *    Non-commercial, ShareAlike, and the interpretation of the term
 *    Non-commercial applicable to the aforementioned license is published
 *    on the web site http://www.open-xchange.com/EN/legal/index.html.
 *
 *    Please make sure that third-party modules and libraries are used
 *    according to their respective licenses.
 *
 *    Any modifications to this package must retain all copyright notices
 *    of the original copyright holder(s) for the original code used.
 *
 *    After any such modifications, the original and derivative code shall remain
 *    under the copyright of the copyright holder(s) and/or original author(s)per
 *    the Attribution and Assignment Agreement that can be located at
 *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
 *    given Attribution for the derivative code and a license granting use.
 *
 *     Copyright (C) 2016-2020 OX Software GmbH
 *     Mail: info@open-xchange.com
 *
 *
 *     This program is free software; you can redistribute it and/or modify it
 *     under the terms of the GNU General Public License, Version 2 as published
 *     by the Free Software Foundation.
 *
 *     This program is distributed in the hope that it will be useful, but
 *     WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY
 *     or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public License
 *     for more details.
 *
 *     You should have received a copy of the GNU General Public License along
 *     with this program; if not, write to the Free Software Foundation, Inc., 59
 *     Temple Place, Suite 330, Boston, MA 02111-1307 USA
 *
 */

package com.openexchange.mobilepush.json.actions;

import javax.servlet.http.HttpServletRequest;
import org.json.JSONException;
import org.json.JSONObject;
import com.openexchange.ajax.requesthandler.AJAXRequestResult;
import com.openexchange.exception.OXException;
import com.openexchange.mobilepush.json.MobilePushRequest;
import com.openexchange.server.ServiceLookup;
import com.openexchange.session.Session;
import com.openexchange.tools.session.ServerSession;


/**
 * {@link PublicInfoAction}
 *
 * @author <a href="mailto:thorben.betten@open-xchange.com">Thorben Betten</a>
 * @since v7.8.0
 */
public class PublicInfoAction extends AbstractMobilePushAction {

    /**
     * Initializes a new {@link PublicInfoAction}.
     */
    public PublicInfoAction(ServiceLookup services) {
        super(services);
    }

    @Override
    protected AJAXRequestResult perform(MobilePushRequest req) throws OXException, JSONException {
        ServerSession session = req.getSession();

        JSONObject jResponse = new JSONObject(2);

        String publicSessionId = (String) session.getParameter(Session.PARAM_ALTERNATIVE_ID);
        if (null == publicSessionId) {
            return new AJAXRequestResult(jResponse, "json");
        }

        HttpServletRequest httpRequest = req.getRequest().optHttpServletRequest();
        if (null == httpRequest) {
            return new AJAXRequestResult(jResponse, "json");
        }

        String publicSessionCookieName = com.openexchange.ajax.LoginServlet.getPublicSessionCookieName(httpRequest, new String[] { Integer.toString(session.getContextId()), Integer.toString(session.getUserId()) });
        jResponse.put(publicSessionCookieName, publicSessionId);
        return new AJAXRequestResult(jResponse, "json");
    }

}
